# CohortDefinition

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | [optional] 
**name** | **str** |  | [optional] 
**period_definitions** | [**list[PeriodDefinition]**](PeriodDefinition.md) |  | [optional] 
**person_set** | [**PersonSet**](PersonSet.md) |  | [optional] 
**patient_metadata_filters** | **list[str]** |  | [optional] 
**model_populations** | [**list[ModelPopulation]**](ModelPopulation.md) |  | [optional] 
**population_id** | **str** |  | [optional] 
**population** | [**Population**](Population.md) |  | [optional] 
**cohort_results** | [**list[CohortResults]**](CohortResults.md) |  | [optional] 
**dataset_id** | **str** |  | [optional] 
**dataset** | [**Dataset**](Dataset.md) |  | [optional] 
**created_at** | **datetime** |  | [optional] 
**created_by** | **str** |  | [optional] 
**updated_at** | **datetime** |  | [optional] 
**archived_at** | **datetime** |  | [optional] 
**last_updated_by** | **str** |  | [optional] 
**version** | **float** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

